
# Class: Groups




URI: [nwb_schema_language:Groups](https://w3id.org/p2p_ld/nwb-schema-language/Groups)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Group]<groups%200..*-++[Groups],[Group])](https://yuml.me/diagram/nofunky;dir:TB/class/[Group]<groups%200..*-++[Groups],[Group])

## Attributes


### Own

 * [groups](groups.md)  <sub>0..\*</sub>
     * Range: [Group](Group.md)
